@@ -119,7 +119,7 @@ reconf['R_RCVD_SPAMBOTS'] = {
 
 -- Charset is missing in message
 reconf['R_MISSING_CHARSET'] = {
-  re = string.format('!is_empty_body() & content_type_is_type(text) & !content_type_has_param(charset) & !%s',
+  re = string.format('!is_empty_body() & content_type_is_type(text) & content_type_is_subtype(plain) & !content_type_has_param(charset) & !%s',
     'compare_transfer_encoding(7bit)'),
   score = 2.5,
   description = 'Charset is missing in a message',
