@@ -83,6 +83,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     $pconfig['use_mfs_var'] = isset($config['system']['use_mfs_tmpvar']) || isset($config['system']['use_mfs_var']);
     $pconfig['use_mfs_tmp'] = isset($config['system']['use_mfs_tmpvar']) || isset($config['system']['use_mfs_tmp']);
     $pconfig['use_swap_file'] = isset($config['system']['use_swap_file']);
+    $pconfig['dhparamusage'] = !empty($config['system']['dhparamusage']) ? $config['system']['dhparamusage'] : null;
     $pconfig['rrdbackup'] = !empty($config['system']['rrdbackup']) ? $config['system']['rrdbackup'] : null;
     $pconfig['dhcpbackup'] = !empty($config['system']['dhcpbackup']) ? $config['system']['dhcpbackup'] : null;
     $pconfig['netflowbackup'] = !empty($config['system']['netflowbackup']) ? $config['system']['netflowbackup'] : null;
@@ -100,7 +101,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         $pconfig['powerd_normal_mode'] = $config['system']['powerd_normal_mode'];
     }
 } elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
-    //
     $input_errors = array();
     $pconfig = $_POST;
 
@@ -147,7 +147,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             unset($config['system']['use_mfs_var']);
         }
 
-        /* the config used to have this, but we've split it up in 17.1 */
+        /* XXX config used to have this, but we've split it up in 17.1 */
         if (isset($config['system']['use_mfs_tmpvar'])) {
             unset($config['system']['use_mfs_tmpvar']);
         }
@@ -189,13 +189,20 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             unset($config['system']['captiveportalbackup']);
         }
 
+        if (!empty($pconfig['dhparamusage'])) {
+            $config['system']['dhparamusage'] = $pconfig['dhparamusage'];
+        } elseif (isset($config['system']['dhparamusage'])) {
+            unset($config['system']['dhparamusage']);
+        }
+
         write_config();
-        $savemsg = get_std_save_message();
 
         system_resolvconf_generate();
         system_cron_configure();
         system_powerd_configure();
         system_kernel_configure();
+
+        $savemsg = get_std_save_message();
     }
 }
 
@@ -221,18 +228,36 @@ include("head.inc");
     }
 ?>
       <section class="col-xs-12">
-        <div class="content-box tab-content table-responsive">
-          <form method="post" name="iform" id="iform">
+        <form method="post" name="iform" id="iform">
+          <div class="content-box tab-content table-responsive __mb">
             <table class="table table-striped opnsense_standard_table_form">
               <tr>
-                <td style="width:22%"><strong><?= gettext('Cryptographic Hardware Acceleration') ?></strong></td>
+                <td style="width:22%"><strong><?= gettext('Cryptography settings') ?></strong></td>
                 <td style="width:78%; text-align:right">
                   <small><?=gettext("full help"); ?> </small>
                   <i class="fa fa-toggle-off text-danger"  style="cursor: pointer;" id="show_all_help_page"></i>
                 </td>
               </tr>
               <tr>
-                <td><a id="help_for_crypto_hardware" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Hardware");?></td>
+                <td><a id="help_for_dhparamusage" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?= gettext('Diffie-Hellman parameters') ?></td>
+                <td>
+                  <select name="dhparamusage" class="selectpicker" data-style="btn-default" id="dhparamusage">
+                    <option value="" <?= $pconfig['dhparamusage'] == '' ? "selected='selected'" : '' ?>><?=gettext('System defaults') ?></option>
+                    <option value="rfc7919" <?= $pconfig['dhparamusage'] == 'rfc7919' ? "selected='selected'" : '' ?>><?=gettext('RFC 7919') ?></option>
+                    <option value="weekly" <?= $pconfig['dhparamusage'] == 'weekly' ? "selected='selected'" : '' ?>><?=gettext('Weekly renewal') ?></option>
+                    <option value="monthly" <?= $pconfig['dhparamusage'] == 'monthly' ? "selected='selected'" : '' ?>><?=gettext('Monthly renewal') ?></option>
+                    <option value="custom" <?= $pconfig['dhparamusage'] == 'custom' ? "selected='selected'" : '' ?>><?=gettext('Custom renewal') ?></option>
+                  </select>
+                  <div class="hidden" data-for="help_for_dhparamusage">
+                    <?=gettext('Diffie-Hellman parameters are statically provided and updated at least twice per year in software updates. ' .
+                               'RFC 7919 predefines static recommendations instead, which are commonly known and verfiable by clients. ' .
+                               'You can choose to regenerate unqiue parameters locally instead according to a predefined or custom schedule. ' .
+                               'In case of custom renewal make sure to set up the respective cron job or rotate the files in some other way.') ?>
+                  </div>
+                </td>
+              </tr>
+              <tr>
+                <td><a id="help_for_crypto_hardware" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?= gettext('Hardware acceleration') ?></td>
                 <td>
                   <select name="crypto_hardware" id="crypto_hardware" class="selectpicker" data-style="btn-default">
                     <option value=""><?=gettext("None"); ?></option>
@@ -262,7 +287,7 @@ include("head.inc");
                 <td><a id="help_for_cryptodev_enable" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Use /dev/crypto");?> </td>
                 <td>
                   <input name="cryptodev_enable" type="checkbox" id="cryptodev_enable" value="yes" <?= !empty($pconfig['cryptodev_enable']) ? "checked=\"checked\"" : "";?> />
-                  <strong><?=gettext("Enable old userland device for cryptographic acceleration"); ?></strong>
+                  <?= gettext('Enable old userland device for cryptographic acceleration') ?>
                   <div class="hidden" data-for="help_for_cryptodev_enable">
                     <?=gettext("Old hardware accelerators like 'safe', 'hifn' or 'ubsec' may only provide userland acceleration to e.g. " .
                                             "OpenVPN by means of the /dev/crypto interface, which can be accessed via the OpenSSL " .
@@ -272,8 +297,13 @@ include("head.inc");
                   </div>
                 </td>
               </tr>
+            </table>
+          </div>
+          <div class="content-box tab-content table-responsive __mb">
+            <table class="table table-striped opnsense_standard_table_form">
               <tr>
-                <th colspan="2" style="vertical-align:top" class="listtopic"><?=gettext("Thermal Sensors"); ?></th>
+                <td style="width:22%"><strong><?= gettext('Thermal Sensors') ?></strong></td>
+                <td style="witdh:78%"></td>
               </tr>
               <tr>
                 <td><a id="help_for_thermal_hardware" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Hardware");?> </td>
@@ -298,8 +328,13 @@ include("head.inc");
                   </div>
                 </td>
               </tr>
+            </table>
+          </div>
+          <div class="content-box tab-content table-responsive __mb">
+            <table class="table table-striped opnsense_standard_table_form">
               <tr>
-                <th colspan="2" style="vertical-align:top" class="listtopic"><?=gettext("Periodic Backups"); ?></th>
+                <td style="width:22%"><strong><?= gettext('Periodic Backups') ?></strong></td>
+                <td style="witdh:78%"></td>
               </tr>
               <tr>
                 <td><a id="help_for_rrdbackup" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Periodic RRD Backup");?></td>
@@ -374,8 +409,13 @@ include("head.inc");
                   </div>
                 </td>
               </tr>
+            </table>
+          </div>
+          <div class="content-box tab-content table-responsive __mb">
+            <table class="table table-striped opnsense_standard_table_form">
               <tr>
-                <th colspan="2" style="vertical-align:top" class="listtopic"><?=gettext("Power Savings"); ?></th>
+                <td style="width:22%"><strong><?= gettext('Power Savings') ?></strong></td>
+                <td style="witdh:78%"></td>
               </tr>
               <tr>
                 <td><a id="help_for_powerd_enable" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Use PowerD"); ?></td>
@@ -401,7 +441,7 @@ include("head.inc");
               <tr>
                 <td><i class="fa fa-info-circle text-muted"></i> <?=gettext('On AC Power Mode') ?></td>
                 <td>
-                  <select name="powerd_ac_mode" class="selectpicker" data-style="btn-default" data-width="auto">
+                  <select name="powerd_ac_mode" class="selectpicker" data-style="btn-default">
                     <option value="hadp" <?=$pconfig['powerd_ac_mode']=="hadp" ? "selected=\"selected\"" : "";?>>
                       <?=gettext("Hiadaptive");?>
                     </option>
@@ -419,7 +459,7 @@ include("head.inc");
               <tr>
                 <td><i class="fa fa-info-circle text-muted"></i> <?=gettext('On Battery Power Mode') ?></td>
                 <td>
-                  <select name="powerd_battery_mode" class="selectpicker" data-style="btn-default" data-width="auto">
+                  <select name="powerd_battery_mode" class="selectpicker" data-style="btn-default">
                     <option value="hadp"<?=$pconfig['powerd_battery_mode']=="hadp" ? "selected=\"selected\"" : "";?>>
                       <?=gettext("Hiadaptive");?>
                     </option>
@@ -438,7 +478,7 @@ include("head.inc");
               <tr>
                 <td><a id="help_for_powerd_normal_mode" href="#" class="showhelp"><i class="fa fa-info-circle text-circle"></i></a> <?=gettext('On Normal Power Mode'); ?></td>
                 <td>
-                  <select name="powerd_normal_mode" class="selectpicker" data-style="btn-default" data-width="auto">
+                  <select name="powerd_normal_mode" class="selectpicker" data-style="btn-default">
                     <option value="hadp"<?=$pconfig['powerd_normal_mode']=="hadp" ? "selected=\"selected\"" : "";?>>
                       <?=gettext("Hiadaptive");?>
                     </option>
@@ -457,21 +497,25 @@ include("head.inc");
                   </div>
                 </td>
               </tr>
+            </table>
+          </div>
+          <div class="content-box tab-content table-responsive __mb">
+            <table class="table table-striped opnsense_standard_table_form">
               <tr>
-                <th colspan="2" style="vertical-align:top" class="listtopic"><?=gettext("Disk / Memory Settings (reboot to apply changes)"); ?></th>
+                <td colspan="2"><strong><?= gettext('Disk / Memory Settings (reboot to apply changes)') ?></strong></td>
               </tr>
               <tr>
-                <td><i class="fa fa-info-circle text-muted"></i> <?=gettext('Swap file'); ?></td>
-                <td>
+                <td style="width:22%"><i class="fa fa-info-circle text-muted"></i> <?=gettext('Swap file'); ?></td>
+                <td style="width=78%">
                   <input name="use_swap_file" type="checkbox" id="use_swap_file" value="yes" <?=!empty($pconfig['use_swap_file']) ? 'checked="checked"' : '';?>/>
-                  <strong><?= gettext('Add a 2 GB swap file to the system') ?></strong>
+                  <?= gettext('Add a 2 GB swap file to the system') ?>
                 </td>
               </tr>
               <tr>
                 <td><a id="help_for_use_mfs_var" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext('/var RAM disk'); ?></td>
                 <td>
                   <input name="use_mfs_var" type="checkbox" id="use_mfs_var" value="yes" <?=!empty($pconfig['use_mfs_var']) ? 'checked="checked"' : '';?>/>
-                  <strong><?=gettext("Use memory file system for /var"); ?></strong>
+                  <?=gettext("Use memory file system for /var"); ?>
                   <div class="hidden" data-for="help_for_use_mfs_var">
                     <?=gettext("Set this if you wish to use /var as a RAM disk (memory file system disks) " .
                       "rather than using the hard disk. Setting this will cause the data /var to be lost on reboot, including log data."); ?>
@@ -482,21 +526,25 @@ include("head.inc");
                 <td><a id="help_for_use_mfs_tmp" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext('/tmp RAM disk'); ?></td>
                 <td>
                   <input name="use_mfs_tmp" type="checkbox" id="use_mfs_tmp" value="yes" <?=!empty($pconfig['use_mfs_tmp']) ? 'checked="checked"' : '';?>/>
-                  <strong><?=gettext('Use memory file system for /tmp'); ?></strong>
+                  <?=gettext('Use memory file system for /tmp'); ?>
                   <div class="hidden" data-for="help_for_use_mfs_tmp">
                     <?= gettext('Set this if you wish to use /tmp as a RAM disk (memory file system disk) rather than using the hard disk.') ?>
                   </div>
                 </td>
               </tr>
+            </table>
+          </div>
+          <div class="content-box tab-content table-responsive">
+            <table class="table table-striped opnsense_standard_table_form">
               <tr>
-                <td>&nbsp;</td>
-                <td>
+                <td style="width:22%"></td>
+                <td style="width:78%">
                   <input name="Submit" type="submit" class="btn btn-primary" value="<?=gettext("Save");?>" />
                 </td>
               </tr>
             </table>
-          </form>
-        </div>
+          </div>
+        </form>
       </section>
     </div>
   </div>
