@@ -177,7 +177,9 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     // For RSA methods, require the CA/Cert.
     switch ($method) {
         case "eap-tls":
+        case "psk_eap-tls":
         case "eap-mschapv2":
+        case "rsa_eap-mschapv2":
         case "eap-radius":
           if ($pconfig['iketype'] != 'ikev2') {
               $input_errors[] = sprintf(gettext("%s can only be used with IKEv2 type VPNs."), strtoupper($method));
@@ -238,21 +240,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         }
     }
 
-    if (!empty($config['ipsec']['phase2'])) {
-        foreach ($config['ipsec']['phase2'] as $phase2) {
-            if ($phase2['ikeid'] == $pconfig['ikeid']) {
-                if (($pconfig['protocol'] == "inet") && ($phase2['mode'] == "tunnel6")) {
-                    $input_errors[] = gettext("There is a Phase 2 using IPv6, you cannot use IPv4.");
-                    break;
-                }
-                if (($pconfig['protocol'] == "inet6") && ($phase2['mode'] == "tunnel")) {
-                    $input_errors[] = gettext("There is a Phase 2 using IPv4, you cannot use IPv6.");
-                    break;
-                }
-            }
-        }
-    }
-
     if ($pconfig['interface'] == 'any' && $pconfig['myid_type'] == "myaddress") {
         $input_errors[] = gettext("Please select an identifier (My Identifier) other then 'any' when selecting 'Any' interface");
     } elseif ($pconfig['myid_type'] == "address" && $pconfig['myid_data'] == "") {
@@ -471,7 +458,9 @@ include("head.inc");
             $(".auth_opt :input").prop( "disabled", true );
             switch ($("#authentication_method").val()) {
                 case 'eap-tls':
+                case 'psk_eap-tls':
                 case 'eap-mschapv2':
+                case 'rsa_eap-mschapv2':
                     $(".auth_eap_tls").show();
                     $(".auth_eap_tls :input").prop( "disabled", false );
                     break;
@@ -490,6 +479,7 @@ include("head.inc");
                 case 'hybrid_rsa_server':
                 case 'xauth_rsa_server':
                 case 'rsasig':
+                case 'rsa_eap-mschapv2':
                     $(".auth_eap_tls_caref").show();
                     $(".auth_eap_tls_caref :input").prop( "disabled", false );
                     $(".auth_eap_tls").show();
@@ -942,6 +932,7 @@ endforeach; ?>
                       <select name="dhgroup">
 <?php
                       $p1_dhgroups = array(
+                        0  => gettext('off'),
                         1  => '1 (768 bit)',
                         2  => '2 (1024 bit)',
                         5  => '5 (1536 bit)',
