@@ -99,7 +99,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         }
     } elseif ($act=="new") {
         // create new
-        $pconfig['interface'] = "wan";
+        $pconfig['interface'] = 'any';
         $init_fields = "auth_user,auth_pass,disable,mode,protocol,interface
             ,local_port,server_addr,server_port,resolve_retry,remote_random,reneg-sec
             ,proxy_addr,proxy_port,proxy_user,proxy_passwd,proxy_authtype,description
@@ -201,7 +201,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             $input_errors[] = gettext("An IPv6 protocol was selected, but the selected interface has no IPv6 address.");
         }
         if (!empty($pconfig['local_port'])) {
-            if (empty($pconfig['local_port']) || !is_numeric($pconfig['local_port']) || $pconfig['local_port'] < 0 || ($pconfig['local_port'] > 65535)) {
+            if (!is_numeric($pconfig['local_port']) || $pconfig['local_port'] < 0 || ($pconfig['local_port'] > 65535)) {
                 $input_errors[] = gettext("The field 'Local port' must contain a valid port, ranging from 0 to 65535.");
             }
             $portused = openvpn_port_used($pconfig['protocol'], $pconfig['interface'], $pconfig['local_port'], $vpnid);
@@ -251,20 +251,16 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
                 }
             }
         }
-        if (!empty($pconfig['tunnel_network'])) {
-            if ($result = openvpn_validate_cidr($pconfig['tunnel_network'], 'IPv4 Tunnel Network', false, "ipv4")) {
-                $input_errors[] = $result;
-            }
-        }
-        if (!empty($pconfig['tunnel_networkv6'])) {
-            if ($result = openvpn_validate_cidr($pconfig['tunnel_networkv6'], 'IPv6 Tunnel Network', false, "ipv6")) {
-                $input_errors[] = $result;
-            }
-        }
-        if ($result = openvpn_validate_cidr($pconfig['remote_network'], 'IPv4 Remote Network', true, "ipv4")) {
+        if ($result = openvpn_validate_cidr($pconfig['tunnel_network'], gettext('IPv4 Tunnel Network'), false, 'ipv4')) {
             $input_errors[] = $result;
         }
-        if ($result = openvpn_validate_cidr($pconfig['remote_networkv6'], 'IPv6 Remote Network', true, "ipv6")) {
+        if ($result = openvpn_validate_cidr($pconfig['tunnel_networkv6'], gettext('IPv6 Tunnel Network'), false, 'ipv6')) {
+            $input_errors[] = $result;
+        }
+        if ($result = openvpn_validate_cidr($pconfig['remote_network'], gettext('IPv4 Remote Network'), true, 'ipv4')) {
+            $input_errors[] = $result;
+        }
+        if ($result = openvpn_validate_cidr($pconfig['remote_networkv6'], gettext('IPv6 Remote Network'), true, 'ipv6')) {
             $input_errors[] = $result;
         }
         if (!empty($pconfig['use_shaper']) && (!is_numeric($pconfig['use_shaper']) || ($pconfig['use_shaper'] <= 0))) {
@@ -366,9 +362,11 @@ legacy_html_escape_form_data($pconfig);
 
 include("head.inc");
 
-$main_buttons = array(
-    array('href'=>'vpn_openvpn_client.php?act=new', 'label'=>gettext("add client")),
-);
+$main_buttons = array();
+
+if (empty($act)) {
+    $main_buttons[] = array('href' => 'vpn_openvpn_client.php?act=new', 'label' => gettext('Add'));
+}
 
 ?>
 
@@ -589,11 +587,11 @@ $( document ).ready(function() {
               </td>
             </tr>
             <tr>
-              <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Protocol");?></td>
+              <td><a id="help_for_protocol" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Protocol");?></td>
               <td>
                 <select name='protocol' class="form-control">
 <?php
-                foreach (array("UDP", "UDP6", "TCP", "TCP6") as $prot) :
+                foreach (openvpn_get_protocols() as $prot):
                     $selected = "";
                     if ($pconfig['protocol'] == $prot) {
                         $selected = "selected=\"selected\"";
@@ -602,6 +600,11 @@ $( document ).ready(function() {
 <?php
                 endforeach; ?>
               </select>
+              <div class="hidden" data-for="help_for_protocol">
+                <?= gettext('Select the protocol family to be used. Note that using both families with UDP/TCP ' .
+                            'does not work with an explicit interface as OpenVPN does not support listening to more ' .
+                            'than one specified IP address. In this case IPv4 is currently assumed.') ?>
+              </div>
             </td>
           </tr>
           <tr>
@@ -656,7 +659,7 @@ $( document ).ready(function() {
               <option value="<?=$iface;?>" <?=$selected;?>><?=htmlspecialchars($ifacename);?></option>
 <?php
               endforeach; ?>
-              </select> <br />
+              </select>
             </td>
           </tr>
           <tr>
@@ -683,13 +686,13 @@ $( document ).ready(function() {
 <?php
                   if (!empty($item)): ?>
                       <label class="act-removerow btn btn-default btn-xs">
-                        <span class="fa fa-minus"></span>
+                        <span class="fa fa-minus fa-fw"></span>
                         <span class="sr-only"><?= gettext('Remove') ?></span>
                       </label>
 <?php
                   else: ?>
                       <label class="act-addrow btn btn-default btn-xs">
-                        <span class="fa fa-plus"></span>
+                        <span class="fa fa-plus fa-fw"></span>
                         <span class="sr-only"><?= gettext('Add') ?></span>
                       </label>
 <?php
@@ -708,14 +711,14 @@ $( document ).ready(function() {
               </table>
               <br/>
               <input name="remote_random" type="checkbox" value="yes" <?= !empty($pconfig['remote_random']) ? 'checked="checked"' : '' ?>/>
-              <strong><?= gettext('Select remote server at random') ?></strong>
+              <?= gettext('Select remote server at random') ?>
             </td>
           </tr>
           <tr>
             <td><a id="help_for_resolve_retry" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Retry DNS resolution"); ?></td>
             <td>
               <input name="resolve_retry" type="checkbox" value="yes" <?= !empty($pconfig['resolve_retry']) ? 'checked="checked"' : '' ?>/>
-              <strong><?= gettext('Infinitely resolve remote server') ?></strong>
+              <?= gettext('Infinitely resolve remote server') ?>
               <div class="hidden" data-for="help_for_resolve_retry">
                 <div><small><?=gettext("Continuously attempt to resolve the server host name. Useful when communicating with a server that is not permanently connected to the Internet"); ?></small></div>
               </div>
@@ -1044,7 +1047,7 @@ $( document ).ready(function() {
             <td>
               <select name="compression" class="form-control">
                 <?php
-                                foreach ($openvpn_compression_modes as $cmode => $cmodedesc) :
+                                foreach (openvpn_compression_modes() as $cmode => $cmodedesc):
                                     $selected = "";
                                     if ($cmode == $pconfig['compression']) {
                                         $selected = " selected=\"selected\"";
@@ -1109,7 +1112,7 @@ $( document ).ready(function() {
           <tr>
             <td style="width:22%"><a id="help_for_custom_options" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Advanced"); ?></td>
             <td style="width:78%">
-              <textarea rows="6" cols="78" name="custom_options" id="custom_options"><?=$pconfig['custom_options'];?></textarea><br />
+              <textarea rows="6" cols="78" name="custom_options" id="custom_options"><?=$pconfig['custom_options'];?></textarea>
               <div class="hidden" data-for="help_for_custom_options">
                 <?=gettext("Enter any additional options you would like to add to the configuration file here."); ?>
               </div>
@@ -1120,7 +1123,7 @@ $( document ).ready(function() {
               <td>
               <select name="verbosity_level" class="form-control">
               <?php
-                            foreach ($openvpn_verbosity_level as $verb_value => $verb_desc) :
+                            foreach (openvpn_verbosity_level() as $verb_value => $verb_desc):
                                 $selected = '';
                                 if ($pconfig['verbosity_level'] == $verb_value) {
                                     $selected = 'selected="selected"';
@@ -1177,7 +1180,7 @@ $( document ).ready(function() {
                 <td><?=gettext("Protocol"); ?></td>
                 <td><?=gettext("Server"); ?></td>
                 <td><?=gettext("Description"); ?></td>
-                <td></td>
+                <td class="text-nowrap"></td>
               </tr>
             </thead>
             <tbody>
@@ -1194,25 +1197,25 @@ $( document ).ready(function() {
                 <td>
                   <input type="checkbox" name="rule[]" value="<?=$i;?>"  />
                   &nbsp;
-                  <a href="#" class="act_toggle" data-id="<?=$i;?>" data-toggle="tooltip" title="<?=(empty($client['disable'])) ? gettext("disable") : gettext("enable");?>">
-                    <span class="glyphicon glyphicon-play <?=(empty($client['disable'])) ? "text-success" : "text-muted";?>"></span>
+                  <a href="#" class="act_toggle" data-id="<?=$i;?>" data-toggle="tooltip" title="<?=(empty($client['disable'])) ? gettext("Disable") : gettext("Enable");?>">
+                    <span class="fa fa-play fa-fw <?=(empty($client['disable'])) ? "text-success" : "text-muted";?>"></span>
                   </a>
                 </td>
                 <td><?= htmlspecialchars($client['protocol']) ?></td>
                 <td><?= htmlspecialchars(implode(', ', $server)) ?></td>
                 <td><?= htmlspecialchars($client['description']) ?></td>
-                <td>
+                <td class="text-nowrap">
                     <a data-id="<?=$i;?>" data-toggle="tooltip" title="<?=gettext("move selected before this item");?>" class="act_move btn btn-default btn-xs">
-                      <span class="glyphicon glyphicon-arrow-left"></span>
+                      <span class="fa fa-arrow-left fa-fw"></span>
                     </a>
                     <a href="vpn_openvpn_client.php?act=edit&amp;id=<?=$i;?>" class="btn btn-default btn-xs">
-                      <span class="glyphicon glyphicon-pencil"></span>
+                      <span class="fa fa-pencil fa-fw"></span>
                     </a>
                     <a data-id="<?=$i;?>" title="<?=gettext("delete client"); ?>" class="act_delete btn btn-default btn-xs">
-                      <span class="fa fa-trash text-muted"></span>
+                      <span class="fa fa-trash fa-fw"></span>
                     </a>
                     <a href="vpn_openvpn_client.php?act=new&amp;dup=<?=$i;?>" class="btn btn-default btn-xs" data-toggle="tooltip" title="<?=gettext("clone client");?>">
-                      <span class="fa fa-clone text-muted"></span>
+                      <span class="fa fa-clone fa-fw"></span>
                     </a>
                 </td>
               </tr>
@@ -1221,12 +1224,12 @@ $( document ).ready(function() {
               endforeach;?>
               <tr>
                 <td colspan="4"></td>
-                <td>
+                <td class="text-nowrap">
                   <a data-id="<?=$i;?>" data-toggle="tooltip" title="<?=gettext("move selected items to end");?>" class="act_move btn btn-default btn-xs">
-                    <span class="glyphicon glyphicon-arrow-down"></span>
+                    <span class="fa fa-arrow-down fa-fw"></span>
                   </a>
                   <a data-id="x" title="<?=gettext("delete selected rules"); ?>" data-toggle="tooltip"  class="act_delete btn btn-default btn-xs">
-                    <span class="fa fa-trash text-muted"></span>
+                    <span class="fa fa-trash fa-fw"></span>
                   </a>
                 </td>
               </tr>
